@@ -17,6 +17,7 @@ def make_issue(
         metaDict={},
         accept_all_changes=False,
         debug=False,
+        segment=None
 ):
     """
     reference:
@@ -40,10 +41,9 @@ def make_issue(
         "suggestions": suggestions,
         "description": description,
         "simpleDescription": simpleDescription,
+        "meta": {"paragraph": paragraph}
     }
 
-    issue["meta"] = {"paragraph": paragraph}
-
     if subCategory:
         issue["meta"]["subCategory"] = subCategory
 
@@ -56,13 +56,17 @@ def make_issue(
     if accept_all_changes:
         issue["meta"]["acceptAllChanges"] = accept_all_changes
 
-    # log warnings if meta_dict overwrites issue["meta"]
     if debug:
+        # log warnings if meta_dict overwrites issue["meta"]
         common = [value for value in metaDict.keys() if value in issue["meta"]]
         for c in common:
             if metaDict[c] != issue["meta"][c]:
                 print(f"Meta_dict {c}:{metaDict[c]} is overwriting issue meta {c}:{issue['meta'][c]}")
 
+        if segment is not None:
+            suggestion = suggestions[0] if len(suggestions) else ''
+            issue['new_segment'] = segment[:start] + suggestion + segment[end:]
+
     issue["meta"].update(metaDict)
 
     return issue
