@@ -83,9 +83,13 @@ class Validator:
         token_length = len(self.nlp(segment.strip()))
         ignored_tokens = self._get_ignored_tokens(segment)
         ignored_length = len(ignored_tokens)
-        return (
-            ignored_length / token_length > self.acceptable_fraction_of_ignorable_tokens
-        )
+        if token_length == 0:
+            return False
+        else:
+            return (
+                ignored_length / token_length
+                > self.acceptable_fraction_of_ignorable_tokens
+            )
 
     def __call__(self, segment: str):
         is_valid = True
